## AWS Serverless Application Model Construct Library

```ts
const sam = require('@aws-cdk/aws-sam');
```

Note: we recommended to use `@aws-cdk/aws-lambda`, `aws-cdk/aws-lambda-event-sources` and `@aws-cdk/aws-apigateway` packages to build 'serverless' applications with the CDK instead of the `AWS::Serverless` resources exposes by `@aws-cdk/aws-sam`.

